==> data-hub-9.14.0-sources.jar: io/intino/datahub/model/Datamart.java <==
package io.intino.datahub.model;

import io.intino.datahub.model.*;

public class Datamart  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
	protected io.intino.datahub.model.Datamart.Snapshots snapshots;
	protected java.util.List<io.intino.datahub.model.Entity> entityList = new java.util.ArrayList<>();
	protected java.util.List<io.intino.datahub.model.Struct> structList = new java.util.ArrayList<>();
	protected java.util.List<io.intino.datahub.model.Timeline> timelineList = new java.util.ArrayList<>();
	protected java.util.List<io.intino.datahub.model.Reel> reelList = new java.util.ArrayList<>();

	public Datamart(io.intino.magritte.framework.Node node) {
		super(node);
	}

	public io.intino.datahub.model.Datamart.Snapshots snapshots() {
		return snapshots;
	}

	public java.util.List<io.intino.datahub.model.Entity> entityList() {
		return java.util.Collections.unmodifiableList(entityList);
	}

	public io.intino.datahub.model.Entity entity(int index) {
		return entityList.get(index);
	}

	public java.util.List<io.intino.datahub.model.Entity> entityList(java.util.function.Predicate<io.intino.datahub.model.Entity> predicate) {
		return entityList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.model.Entity entity(java.util.function.Predicate<io.intino.datahub.model.Entity> predicate) {
		return entityList().stream().filter(predicate).findFirst().orElse(null);
	}

	public java.util.List<io.intino.datahub.model.Struct> structList() {
		return java.util.Collections.unmodifiableList(structList);
	}

	public io.intino.datahub.model.Struct struct(int index) {
		return structList.get(index);
	}

	public java.util.List<io.intino.datahub.model.Struct> structList(java.util.function.Predicate<io.intino.datahub.model.Struct> predicate) {
		return structList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.model.Struct struct(java.util.function.Predicate<io.intino.datahub.model.Struct> predicate) {
		return structList().stream().filter(predicate).findFirst().orElse(null);
	}

	public java.util.List<io.intino.datahub.model.Timeline> timelineList() {
		return java.util.Collections.unmodifiableList(timelineList);
	}

	public io.intino.datahub.model.Timeline timeline(int index) {
		return timelineList.get(index);
	}

	public java.util.List<io.intino.datahub.model.Timeline> timelineList(java.util.function.Predicate<io.intino.datahub.model.Timeline> predicate) {
		return timelineList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.model.Timeline timeline(java.util.function.Predicate<io.intino.datahub.model.Timeline> predicate) {
		return timelineList().stream().filter(predicate).findFirst().orElse(null);
	}

	public java.util.List<io.intino.datahub.model.Reel> reelList() {
		return java.util.Collections.unmodifiableList(reelList);
	}

	public io.intino.datahub.model.Reel reel(int index) {
		return reelList.get(index);
	}

	public java.util.List<io.intino.datahub.model.Reel> reelList(java.util.function.Predicate<io.intino.datahub.model.Reel> predicate) {
		return reelList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.model.Reel reel(java.util.function.Predicate<io.intino.datahub.model.Reel> predicate) {
		return reelList().stream().filter(predicate).findFirst().orElse(null);
	}

	protected java.util.List<io.intino.magritte.framework.Node> componentList$() {
		java.util.Set<io.intino.magritte.framework.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		if (snapshots != null) components.add(this.snapshots.core$());
		new java.util.ArrayList<>(entityList).forEach(c -> components.add(c.core$()));
		new java.util.ArrayList<>(structList).forEach(c -> components.add(c.core$()));
		new java.util.ArrayList<>(timelineList).forEach(c -> components.add(c.core$()));
		new java.util.ArrayList<>(reelList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		return map;
	}

	@Override
	protected void addNode$(io.intino.magritte.framework.Node node) {
		super.addNode$(node);
		if (node.is("Datamart$Snapshots")) this.snapshots = node.as(io.intino.datahub.model.Datamart.Snapshots.class);
		if (node.is("Entity")) this.entityList.add(node.as(io.intino.datahub.model.Entity.class));
		if (node.is("Struct")) this.structList.add(node.as(io.intino.datahub.model.Struct.class));
		if (node.is("Timeline")) this.timelineList.add(node.as(io.intino.datahub.model.Timeline.class));
		if (node.is("Reel")) this.reelList.add(node.as(io.intino.datahub.model.Reel.class));
	}

	@Override
	protected void removeNode$(io.intino.magritte.framework.Node node) {
		super.removeNode$(node);
		if (node.is("Datamart$Snapshots")) this.snapshots = null;
		if (node.is("Entity")) this.entityList.remove(node.as(io.intino.datahub.model.Entity.class));
		if (node.is("Struct")) this.structList.remove(node.as(io.intino.datahub.model.Struct.class));
		if (node.is("Timeline")) this.timelineList.remove(node.as(io.intino.datahub.model.Timeline.class));
		if (node.is("Reel")) this.reelList.remove(node.as(io.intino.datahub.model.Reel.class));
	}

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.datahub.model.Datamart.Snapshots snapshots() {
			io.intino.datahub.model.Datamart.Snapshots newElement = core$().graph().concept(io.intino.datahub.model.Datamart.Snapshots.class).createNode(this.name, core$()).as(io.intino.datahub.model.Datamart.Snapshots.class);

			return newElement;
		}

		public io.intino.datahub.model.Entity entity() {
			io.intino.datahub.model.Entity newElement = core$().graph().concept(io.intino.datahub.model.Entity.class).createNode(this.name, core$()).as(io.intino.datahub.model.Entity.class);

			return newElement;
		}

		public io.intino.datahub.model.Struct struct() {
			io.intino.datahub.model.Struct newElement = core$().graph().concept(io.intino.datahub.model.Struct.class).createNode(this.name, core$()).as(io.intino.datahub.model.Struct.class);

			return newElement;
		}

		public io.intino.datahub.model.Timeline timeline(io.intino.datahub.model.Datalake.Tank.Measurement tank, io.intino.datahub.model.Entity entity) {
			io.intino.datahub.model.Timeline newElement = core$().graph().concept(io.intino.datahub.model.Timeline.class).createNode(this.name, core$()).as(io.intino.datahub.model.Timeline.class);
			newElement.core$().set(newElement, "tank", java.util.Collections.singletonList(tank));
			newElement.core$().set(newElement, "entity", java.util.Collections.singletonList(entity));
			return newElement;
		}

		public io.intino.datahub.model.Reel reel(io.intino.datahub.model.Attribute signals, io.intino.datahub.model.Attribute groupSource, io.intino.datahub.model.Attribute entitySource) {
			io.intino.datahub.model.Reel newElement = core$().graph().concept(io.intino.datahub.model.Reel.class).createNode(this.name, core$()).as(io.intino.datahub.model.Reel.class);
			newElement.core$().set(newElement, "signals", java.util.Collections.singletonList(signals));
			newElement.core$().set(newElement, "groupSource", java.util.Collections.singletonList(groupSource));
			newElement.core$().set(newElement, "entitySource", java.util.Collections.singletonList(entitySource));
			return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void entity(java.util.function.Predicate<io.intino.datahub.model.Entity> filter) {
			new java.util.ArrayList<>(entityList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}

		public void struct(java.util.function.Predicate<io.intino.datahub.model.Struct> filter) {
			new java.util.ArrayList<>(structList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}

		public void timeline(java.util.function.Predicate<io.intino.datahub.model.Timeline> filter) {
			new java.util.ArrayList<>(timelineList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}

		public void reel(java.util.function.Predicate<io.intino.datahub.model.Reel> filter) {
			new java.util.ArrayList<>(reelList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}
	}

	public static class Snapshots  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected io.intino.datahub.model.rules.SnapshotScale scale;
		protected io.intino.datahub.model.rules.DayOfWeek firstDayOfWeek;
		protected int maxCount;

		public Snapshots(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public io.intino.datahub.model.rules.SnapshotScale scale() {
			return scale;
		}

		public io.intino.datahub.model.rules.DayOfWeek firstDayOfWeek() {
			return firstDayOfWeek;
		}

		public int maxCount() {
			return maxCount;
		}

		public Snapshots scale(io.intino.datahub.model.rules.SnapshotScale value) {
			this.scale = value;
			return (Snapshots) this;
		}

		public Snapshots firstDayOfWeek(io.intino.datahub.model.rules.DayOfWeek value) {
			this.firstDayOfWeek = value;
			return (Snapshots) this;
		}

		public Snapshots maxCount(int value) {
			this.maxCount = value;
			return (Snapshots) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("scale", new java.util.ArrayList(java.util.Collections.singletonList(this.scale)));
			map.put("firstDayOfWeek", new java.util.ArrayList(java.util.Collections.singletonList(this.firstDayOfWeek)));
			map.put("maxCount", new java.util.ArrayList(java.util.Collections.singletonList(this.maxCount)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("scale")) this.scale = io.intino.magritte.framework.loaders.WordLoader.load(values, io.intino.datahub.model.rules.SnapshotScale.class, this).get(0);
			else if (name.equalsIgnoreCase("firstDayOfWeek")) this.firstDayOfWeek = io.intino.magritte.framework.loaders.WordLoader.load(values, io.intino.datahub.model.rules.DayOfWeek.class, this).get(0);
			else if (name.equalsIgnoreCase("maxCount")) this.maxCount = io.intino.magritte.framework.loaders.IntegerLoader.load(values, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("scale")) this.scale = (io.intino.datahub.model.rules.SnapshotScale) values.get(0);
			else if (name.equalsIgnoreCase("firstDayOfWeek")) this.firstDayOfWeek = (io.intino.datahub.model.rules.DayOfWeek) values.get(0);
			else if (name.equalsIgnoreCase("maxCount")) this.maxCount = (java.lang.Integer) values.get(0);
		}

		public io.intino.datahub.model.NessGraph graph() {
			return (io.intino.datahub.model.NessGraph) core$().graph().as(io.intino.datahub.model.NessGraph.class);
		}
	}


	public io.intino.datahub.model.NessGraph graph() {
		return (io.intino.datahub.model.NessGraph) core$().graph().as(io.intino.datahub.model.NessGraph.class);
	}
}

==> data-hub-11.0.1-sources.jar: io/intino/datahub/model/Datamart.java <==
package io.intino.datahub.model;

import io.intino.datahub.model.*;

public class Datamart  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
	protected io.intino.datahub.model.Datamart.Snapshots snapshots;
	protected java.util.List<io.intino.datahub.model.Entity> entityList = new java.util.ArrayList<>();
	protected java.util.List<io.intino.datahub.model.Struct> structList = new java.util.ArrayList<>();
	protected java.util.List<io.intino.datahub.model.Timeline> timelineList = new java.util.ArrayList<>();
	protected java.util.List<io.intino.datahub.model.Reel> reelList = new java.util.ArrayList<>();

	public Datamart(io.intino.magritte.framework.Node node) {
		super(node);
	}

	public io.intino.datahub.model.Datamart.Snapshots snapshots() {
		return snapshots;
	}

	public java.util.List<io.intino.datahub.model.Entity> entityList() {
		return java.util.Collections.unmodifiableList(entityList);
	}

	public io.intino.datahub.model.Entity entity(int index) {
		return entityList.get(index);
	}

	public java.util.List<io.intino.datahub.model.Entity> entityList(java.util.function.Predicate<io.intino.datahub.model.Entity> predicate) {
		return entityList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.model.Entity entity(java.util.function.Predicate<io.intino.datahub.model.Entity> predicate) {
		return entityList().stream().filter(predicate).findFirst().orElse(null);
	}

	public java.util.List<io.intino.datahub.model.Struct> structList() {
		return java.util.Collections.unmodifiableList(structList);
	}

	public io.intino.datahub.model.Struct struct(int index) {
		return structList.get(index);
	}

	public java.util.List<io.intino.datahub.model.Struct> structList(java.util.function.Predicate<io.intino.datahub.model.Struct> predicate) {
		return structList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.model.Struct struct(java.util.function.Predicate<io.intino.datahub.model.Struct> predicate) {
		return structList().stream().filter(predicate).findFirst().orElse(null);
	}

	public java.util.List<io.intino.datahub.model.Timeline> timelineList() {
		return java.util.Collections.unmodifiableList(timelineList);
	}

	public io.intino.datahub.model.Timeline timeline(int index) {
		return timelineList.get(index);
	}

	public java.util.List<io.intino.datahub.model.Timeline> timelineList(java.util.function.Predicate<io.intino.datahub.model.Timeline> predicate) {
		return timelineList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.model.Timeline timeline(java.util.function.Predicate<io.intino.datahub.model.Timeline> predicate) {
		return timelineList().stream().filter(predicate).findFirst().orElse(null);
	}

	public java.util.List<io.intino.datahub.model.Reel> reelList() {
		return java.util.Collections.unmodifiableList(reelList);
	}

	public io.intino.datahub.model.Reel reel(int index) {
		return reelList.get(index);
	}

	public java.util.List<io.intino.datahub.model.Reel> reelList(java.util.function.Predicate<io.intino.datahub.model.Reel> predicate) {
		return reelList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.model.Reel reel(java.util.function.Predicate<io.intino.datahub.model.Reel> predicate) {
		return reelList().stream().filter(predicate).findFirst().orElse(null);
	}

	protected java.util.List<io.intino.magritte.framework.Node> componentList$() {
		java.util.Set<io.intino.magritte.framework.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		if (snapshots != null) components.add(this.snapshots.core$());
		new java.util.ArrayList<>(entityList).forEach(c -> components.add(c.core$()));
		new java.util.ArrayList<>(structList).forEach(c -> components.add(c.core$()));
		new java.util.ArrayList<>(timelineList).forEach(c -> components.add(c.core$()));
		new java.util.ArrayList<>(reelList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		return map;
	}

	@Override
	protected void addNode$(io.intino.magritte.framework.Node node) {
		super.addNode$(node);
		if (node.is("Datamart$Snapshots")) this.snapshots = node.as(io.intino.datahub.model.Datamart.Snapshots.class);
		if (node.is("Entity")) this.entityList.add(node.as(io.intino.datahub.model.Entity.class));
		if (node.is("Struct")) this.structList.add(node.as(io.intino.datahub.model.Struct.class));
		if (node.is("Timeline")) this.timelineList.add(node.as(io.intino.datahub.model.Timeline.class));
		if (node.is("Reel")) this.reelList.add(node.as(io.intino.datahub.model.Reel.class));
	}

	@Override
	protected void removeNode$(io.intino.magritte.framework.Node node) {
		super.removeNode$(node);
		if (node.is("Datamart$Snapshots")) this.snapshots = null;
		if (node.is("Entity")) this.entityList.remove(node.as(io.intino.datahub.model.Entity.class));
		if (node.is("Struct")) this.structList.remove(node.as(io.intino.datahub.model.Struct.class));
		if (node.is("Timeline")) this.timelineList.remove(node.as(io.intino.datahub.model.Timeline.class));
		if (node.is("Reel")) this.reelList.remove(node.as(io.intino.datahub.model.Reel.class));
	}

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.datahub.model.Datamart.Snapshots snapshots() {
			io.intino.datahub.model.Datamart.Snapshots newElement = core$().graph().concept(io.intino.datahub.model.Datamart.Snapshots.class).createNode(this.name, core$()).as(io.intino.datahub.model.Datamart.Snapshots.class);

			return newElement;
		}

		public io.intino.datahub.model.Entity entity() {
			io.intino.datahub.model.Entity newElement = core$().graph().concept(io.intino.datahub.model.Entity.class).createNode(this.name, core$()).as(io.intino.datahub.model.Entity.class);

			return newElement;
		}

		public io.intino.datahub.model.Struct struct() {
			io.intino.datahub.model.Struct newElement = core$().graph().concept(io.intino.datahub.model.Struct.class).createNode(this.name, core$()).as(io.intino.datahub.model.Struct.class);

			return newElement;
		}

		public io.intino.datahub.model.Timeline timeline(io.intino.datahub.model.Entity entity) {
			io.intino.datahub.model.Timeline newElement = core$().graph().concept(io.intino.datahub.model.Timeline.class).createNode(this.name, core$()).as(io.intino.datahub.model.Timeline.class);
			newElement.core$().set(newElement, "entity", java.util.Collections.singletonList(entity));
			return newElement;
		}

		public io.intino.datahub.model.Reel reel(io.intino.datahub.model.Attribute signals, io.intino.datahub.model.Attribute groupSource, io.intino.datahub.model.Attribute entitySource) {
			io.intino.datahub.model.Reel newElement = core$().graph().concept(io.intino.datahub.model.Reel.class).createNode(this.name, core$()).as(io.intino.datahub.model.Reel.class);
			newElement.core$().set(newElement, "signals", java.util.Collections.singletonList(signals));
			newElement.core$().set(newElement, "groupSource", java.util.Collections.singletonList(groupSource));
			newElement.core$().set(newElement, "entitySource", java.util.Collections.singletonList(entitySource));
			return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void entity(java.util.function.Predicate<io.intino.datahub.model.Entity> filter) {
			new java.util.ArrayList<>(entityList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}

		public void struct(java.util.function.Predicate<io.intino.datahub.model.Struct> filter) {
			new java.util.ArrayList<>(structList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}

		public void timeline(java.util.function.Predicate<io.intino.datahub.model.Timeline> filter) {
			new java.util.ArrayList<>(timelineList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}

		public void reel(java.util.function.Predicate<io.intino.datahub.model.Reel> filter) {
			new java.util.ArrayList<>(reelList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}
	}

	public static class Snapshots  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected io.intino.datahub.model.rules.SnapshotScale scale;
		protected io.intino.datahub.model.rules.DayOfWeek firstDayOfWeek;
		protected int maxCount;

		public Snapshots(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public io.intino.datahub.model.rules.SnapshotScale scale() {
			return scale;
		}

		public io.intino.datahub.model.rules.DayOfWeek firstDayOfWeek() {
			return firstDayOfWeek;
		}

		public int maxCount() {
			return maxCount;
		}

		public Snapshots scale(io.intino.datahub.model.rules.SnapshotScale value) {
			this.scale = value;
			return (Snapshots) this;
		}

		public Snapshots firstDayOfWeek(io.intino.datahub.model.rules.DayOfWeek value) {
			this.firstDayOfWeek = value;
			return (Snapshots) this;
		}

		public Snapshots maxCount(int value) {
			this.maxCount = value;
			return (Snapshots) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("scale", new java.util.ArrayList(java.util.Collections.singletonList(this.scale)));
			map.put("firstDayOfWeek", new java.util.ArrayList(java.util.Collections.singletonList(this.firstDayOfWeek)));
			map.put("maxCount", new java.util.ArrayList(java.util.Collections.singletonList(this.maxCount)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("scale")) this.scale = io.intino.magritte.framework.loaders.WordLoader.load(values, io.intino.datahub.model.rules.SnapshotScale.class, this).get(0);
			else if (name.equalsIgnoreCase("firstDayOfWeek")) this.firstDayOfWeek = io.intino.magritte.framework.loaders.WordLoader.load(values, io.intino.datahub.model.rules.DayOfWeek.class, this).get(0);
			else if (name.equalsIgnoreCase("maxCount")) this.maxCount = io.intino.magritte.framework.loaders.IntegerLoader.load(values, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("scale")) this.scale = (io.intino.datahub.model.rules.SnapshotScale) values.get(0);
			else if (name.equalsIgnoreCase("firstDayOfWeek")) this.firstDayOfWeek = (io.intino.datahub.model.rules.DayOfWeek) values.get(0);
			else if (name.equalsIgnoreCase("maxCount")) this.maxCount = (java.lang.Integer) values.get(0);
		}

		public io.intino.datahub.model.NessGraph graph() {
			return (io.intino.datahub.model.NessGraph) core$().graph().as(io.intino.datahub.model.NessGraph.class);
		}
	}


	public io.intino.datahub.model.NessGraph graph() {
		return (io.intino.datahub.model.NessGraph) core$().graph().as(io.intino.datahub.model.NessGraph.class);
	}
}
